@@ -1,5 +1,3 @@
-from django.utils import timezone
-from django.contrib.auth.models import User
 from rest_framework import authentication
 from rest_framework import exceptions
 
@@ -8,19 +6,28 @@ from drf_temptoken.models import TempToken
 
 class TempTokenAuthentication(authentication.BaseAuthentication):
     def authenticate(self, request):
+        query = request.GET
+
         header = request.META.get(f'HTTP_{utils.TMP_TOKEN_AUTH_HEADER}'.upper())
 
-        print(request.META)
+        param = utils.get_query_param()
 
-        if not header:
+        if not header and not param:
             return None
 
         header_prefix = utils.get_header_prefix()
 
-        if header_prefix not in header:
+        value = query.get(param) 
+
+        has_prefix = header and header_prefix in header
+
+        if not has_prefix and not value:
             return None
 
-        _, key = header.split(header_prefix)
+        if value:
+            key = value
+        else:
+            _, key = header.split(header_prefix)
 
         try:
             token = TempToken.objects.get(key=key)
